# shieldpython
A Python Module for Interacting with the Intrusion Shield CloudAPI

This module brings together multiple disparate methods for accessing DNS and **Intrusion**'s Shield rules, and transforms their output to provide a common interface that is compatible with the widest possible range of DNS applications.
